@@ -1,7 +1,7 @@
 skip_on_cran()
 
 test_that("gn_parse_tidy", {
-  x <- c("Quadrella steyermarkii (Standl.) Iltis &amp; Cornejo",
+  x <- c("Quadrella steyermarkii (Standl.) Iltis & Cornejo",
     "Parus major Linnaeus, 1788", "Helianthus annuus var. texanus")
   z <- gn_parse_tidy(x)
 
